@@ -10,11 +10,11 @@ Test::BinaryData - compare two things, give hex dumps if they differ
 
 =head1 VERSION
 
-version 0.007
+version 0.008
 
 =cut
 
-our $VERSION = '0.007';
+our $VERSION = '0.008';
 
 =head1 SYNOPSIS
 
@@ -86,14 +86,14 @@ require Exporter;
 @Test::BinaryData::ISA = qw(Exporter);
 @Test::BinaryData::EXPORT = qw(is_binary);
 
-my $Test = Test::Builder->new;
-
 sub import {
   my($self) = shift;
   my $pack = caller;
 
+  my $Test = Test::Builder->new;
+
   $Test->exported_to($pack);
-  $Test->plan(@_);
+  $Test->plan(@_) if @_;
 
   $self->export_to_level(1, $self, @Test::BinaryData::EXPORT);
 }
@@ -137,6 +137,8 @@ sub _widths {
 sub is_binary {
   my ($got, $expected, $comment, $arg) = @_;
 
+  my $Test = Test::Builder->new;
+
   $arg ||= {};
 
   unless (defined $arg->{columns}) {
